( function () {

	angular.module('eTakeAway')
	.config( function ($stateProvider, $urlRouterProvider)
	{
		$stateProvider

		.state('app', {
			url: "/app",
			abstract: true,
			templateUrl: "templates/parentTemplate.html",
			controller: "AppCtrl"
		})

		.state('app.welcome', {
			url: '/welcome',
			views: {
				'menuContent': {
					templateUrl: 'templates/welcome.html',
					controller: 'WelcomeCtrl'
				}
			},
			params: {
				referrer: 'default'
			}
		})

		.state('app.main', {
			url: '/main',
			views: {
				'menuContent': {
					templateUrl: 'templates/main.html',
					controller: 'MainCtrl'
				}
			},
			resolve: {
				offers: function (eTakeAwayService, $ionicLoading) {
					$ionicLoading.show();
					return eTakeAwayService.getOffers();
				},
				storeStatus: function (eTakeAwayService, $ionicLoading) {
					$ionicLoading.show();
					return eTakeAwayService.getStoreOpened();
				},
				storeInfo: function (eTakeAwayService, $ionicLoading) {
					$ionicLoading.show();
					return eTakeAwayService.getStoreInfo();
				}
			}
		})

		.state('app.login', {
			url: '/login',
			views: {
				'menuContent': {
					templateUrl: 'templates/login.html',
					controller: 'LoginCtrl'
				}
			},
			params: {
				referrer: 'default'
			}
		})

		.state('app.signup', {
			url: '/signup',
			views: {
				'menuContent': {
					templateUrl: 'templates/signup.html',
					controller: 'registrationCtrl'
				}
			},
			params: {
				referrer: 'default'
			}
		})

		.state('loading', {
                        cache: false,
			url: '/loading',
			templateUrl: 'templates/loading.html',
			controller: 'LoadingCtrl'
		})

		.state('app.categories', {
			url: '/categories',
			views:
			{
				'menuContent': {
					templateUrl: 'templates/categories.html',
					controller: 'Categories'
				}
			},
			resolve: {
				menu: function ($ionicLoading, dbService) {
					// $ionicLoading.show();
					return dbService.prepareDatabase();
				},
				storeInfo: function ($ionicLoading, eTakeAwayService) {
					// $ionicLoading.show();
					return eTakeAwayService.getStoreInfo();
				},
        storeStatus: function (eTakeAwayService, $ionicLoading) {
            $ionicLoading.show();
            return eTakeAwayService.getStoreOpened();
        }
			}

		})

		.state('app.subCategories', {
			url: '/subCategories/:parent_id/:catDescription',
			views:
			{
				'menuContent': {
					templateUrl: 'templates/subCategories.html',
					controller: 'SubCategories'
				}
			},
			
			resolve: {
				subCategories: function ($stateParams, dbService,$ionicLoading) {
					$ionicLoading.show();
					return dbService.getProducts($stateParams.parent_id);
				},
                                catDescription:function ($stateParams, dbService,$ionicLoading) {
                                    return $stateParams.catDescription
                                }
//				menu: function ( dbService) {
//                                    return dbService.getMenu();
//				}
			}
		})

		.state('app.products', {
			url: '/products/:category_id/:catDescription',
			views: {
				'menuContent': {
					templateUrl: 'templates/products.html',
					controller: 'Products'
				}
			},
			resolve: {
				products: function ($stateParams, dbService,$ionicLoading) {
					$ionicLoading.show();
					return dbService.getProducts($stateParams.category_id);
				},
                                catDescription:function ($stateParams, dbService,$ionicLoading) {
                                    return $stateParams.catDescription
                                }
//                                menu: function (dbService) {
//					return dbService.getMenu();
//				}
        }
		})

		.state('app.productOptions', {
			url: '/productOptions/:product_id',
			views: {
				'menuContent': {
					templateUrl: 'templates/productOptions.html',
					controller: 'ProductOptions'
				}
			},
			resolve: {
				product: function ($stateParams, dbService, $ionicLoading) {
					$ionicLoading.show();
					return dbService.getProduct($stateParams.product_id);
				}
			}
		})

		.state('app.cartDetails', {
			url: '/cartDetails',
			views: {
				'menuContent': {
					templateUrl: 'templates/cartDetails.html',
					controller: 'CartDetails'
				}
			},
			resolve: {
				cart: function (eTakeAwayService) {
					var customer_id = localStorage.getItem('customer_id');
					// console.log(customer_id);
					if (customer_id) {
						var cartData = {
							customer_id: customer_id,
							address_id: localStorage.getItem('address_id')
						};
						return eTakeAwayService.cartDetails(cartData);
					}
					else {
						return null;
					}
				},
        storeStatus: function (eTakeAwayService, $ionicLoading) {
            $ionicLoading.show();
            return eTakeAwayService.getStoreOpened();
        }
			}
		})

		.state('app.shippingMethod', {
			url: '/shippingMethod',
			views: {
				'menuContent': {
					templateUrl: 'templates/shippingMethod.html',
					controller: 'ShippingMethod'
				}
			},
      resolve:{
        cart: function (eTakeAwayService) {
          var customer_id = localStorage.getItem('customer_id');
          if (customer_id) {
            var cartData = {
              customer_id: customer_id,
              address_id: localStorage.getItem('address_id')
            };
            return eTakeAwayService.cartDetails(cartData);
          }
          else {
            return null;
          }
        }
      }
		})

    .state('app.chooseAddress', {
      url: '/chooseAddress',
      views: {
        'menuContent': {
          templateUrl: 'templates/chooseAddress.html',
          controller: 'ChooseAddressCtrl'
        }
      },
      resolve: {
        addresses: function (eTakeAwayService) {
          return eTakeAwayService.getCustomerAddresses(localStorage.getItem('customer_id'));
        }
      }
    })

		.state('app.paymentMethod', {
			url: '/paymentMethod',
			views: {
				'menuContent': {
					templateUrl: 'templates/paymentMethod.html',
					controller: 'PaymentMethod'
				}
			}
		})

		.state('app.deliveryAddress', {
			url: '/deliveryAddress/:address_id',
                        cache: false,
			views: {
				'menuContent': {
					templateUrl: 'templates/deliveryAddress.html',
					controller: 'DeliveryAddress'
				}
			},
			resolve: {
				addresses: function (eTakeAwayService) {
					return eTakeAwayService.getCustomerAddresses(localStorage.getItem('customer_id'));
				},
                                customer: function (eTakeAwayService,$ionicLoading) {
                                    return eTakeAwayService.getCustomerDetails(localStorage.getItem('customer_id'));
                                },
				cart: function (eTakeAwayService) {
                                    var customer_id = localStorage.getItem('customer_id');
                                  //  console.log(customer_id);
                                    if (customer_id) {
                                        var cartData = {
                                            customer_id: customer_id,
                                            address_id: localStorage.getItem('address_id')
                                        }
                                        return eTakeAwayService.cartDetails(cartData);
                                    }
                                    else {
                                        return null;
                                    }
                                }
                        }
		})

		.state('app.confirmOrder', {
			url: '/confirmOrder',
			views: {
				'menuContent': {
					templateUrl: 'templates/confirmOrder.html',
					controller: 'ConfirmOrder'
				}
			},
            resolve: {
                storeInfo: function (eTakeAwayService, $ionicLoading) {
                    $ionicLoading.show();
                    return eTakeAwayService.getStoreInfo();
                }
            }
		})

		.state('app.accountDetail', {
			url: '/accountDetail',
			views: {
				'menuContent': {
					templateUrl: 'templates/accountDetail.html',
					controller: 'AccountDetail'
				}
			},
			resolve: {
				customer: function (eTakeAwayService) {
					return eTakeAwayService.getCustomerDetails(localStorage.getItem('customer_id'));
				},
                recentOrders:function(eTakeAwayService){
                    return eTakeAwayService.getRecentOrders(localStorage.getItem('customer_id'));
                },
                cart: function (eTakeAwayService) {
                    var customer_id = localStorage.getItem('customer_id');
                //    console.log(customer_id);
                    if (customer_id) {
                        var cartData = {
                            customer_id: customer_id,
                            address_id: localStorage.getItem('address_id')
                        }
                        return eTakeAwayService.cartDetails(cartData);
                    }
                    else {
                        return null;
                    }
                }
			}
		})

        .state('app.recentOrders', {
            url: '/recentOrders',
            views: {
                'menuContent': {
                    templateUrl: 'templates/recentOrders.html',
                    controller: 'RecentOrdersCtrl'
                }
            },
            resolve: {
                recentOrders:function(eTakeAwayService){
                    return eTakeAwayService.getRecentOrders(localStorage.getItem('customer_id'));
                }
            }
        })

        .state('app.reOrder', {
            url: '/reorder/:id',
            views: {
                'menuContent': {
                    templateUrl: 'templates/reOrder.html',
                    controller: 'ReOrderCtrl'
                }
            },
            resolve:{
                addresses: function (eTakeAwayService) {
                    return eTakeAwayService.getCustomerAddresses(localStorage.getItem('customer_id'));
                },
                customer: function (eTakeAwayService) {
                    return eTakeAwayService.getCustomerDetails(localStorage.getItem('customer_id'));
                },
                orderDetails:function(eTakeAwayService,$stateParams,$rootScope){
                    return eTakeAwayService.getOrderDetails($stateParams.id,$rootScope.customer_id)
                },
                cart: function (eTakeAwayService) {
                    var customer_id = localStorage.getItem('customer_id');
                //    console.log(customer_id);
                    if (customer_id) {
                        var cartData = {
                            customer_id: customer_id,
                            address_id: localStorage.getItem('address_id')
                        }
                        return eTakeAwayService.cartDetails(cartData);
                    }
                    else {
                        return null;
                    }
                }
            }
        })


		.state('app.feedback', {
			url: '/feedback',
			views: {
				'menuContent': {
					templateUrl: 'templates/feedback.html',
					controller: 'FeedbackCtrl'
				}
			}
		})

		.state('app.information', {
			url: '/information',
			views: {
				'menuContent': {
					templateUrl: 'templates/information.html',
					controller: 'InformationCtrl'
				}
			}
		})

		.state('app.changePassword', {
			url: '/changePassword',
			views: {
				'menuContent': {
					templateUrl: 'templates/changePassword.html',
					controller: 'ChangePassword'
				}
			}
		})

		.state('app.forgetPassword', {
			url: '/forgetPassword',
			views: {
				'menuContent': {
					templateUrl: 'templates/forgetPassword.html',
					controller: 'ForgetPassword'
				}
			}
		})

		.state('app.editAccountInfo', {
			url: '/editAccountInfo',
			views: {
				'menuContent': {
					templateUrl: 'templates/editAccountInfo.html',
					controller: 'EditAccountInfoCtrl'
				}
			},
			resolve: {
				customer: function (eTakeAwayService,$ionicLoading) {
					$ionicLoading.show();
					return eTakeAwayService.getCustomerDetails(localStorage.getItem('customer_id'));
				}
			}
		})

		.state('app.addressBook', {
			url: '/addressBook',
			views: {
				'menuContent': {
					templateUrl: 'templates/addressBook.html',
					controller: 'AddressBookCtrl'
				}
			},
			resolve: {
				addresses: function (eTakeAwayService) {
					return eTakeAwayService.getCustomerAddresses(localStorage.getItem('customer_id'));
				}
			}
		})

		.state('app.editAddress', {
			url: '/editAddress',
			views: {
				'menuContent': {
					templateUrl: 'templates/editAddress.html',
					controller: 'EditAddressCtrl'
				}
			},
			params: {
				addressId: 'default',
				firstname: 'default',
				lastname: 'default',
				address: 'default',
				postcode: 'default',
                                houseno: 'default',
                                telephone: 'default'
			}
		})


	.state('app.addAddress', {
		url: '/addAddress',
		views: {
			'menuContent': {
				templateUrl: 'templates/addAddress.html',
				controller: 'AddAddressCtrl'
			}
		}
	})
		$urlRouterProvider.otherwise('/loading');
	})

}());
