( function () {

	angular.module('services')
		.factory('cartService', function ($rootScope) {
			var cart = [];
			var deliveryMethod = "";
			var payementMethod = "";

			function addToCart(product) {
				cart.push(product);
				$rootScope.cartSize++;
				$rootScope.cartTotal = getTotalPrice();
			}

			function removeFromCart(product_id) {
				cart.forEach(function (product, i) {
					if (product.product_id == product_id) {
						cart.splice(i, 1);
					}
				});
				$rootScope.cartSize--;
				$rootScope.cartTotal = getTotalPrice();
			}

			function viewCart() {
				return cart;
			}

			function getCartSize() {
				return (cart.length) ? cart.length : 0;
			}

			function checkProduct(product_id) {
				var duplicate = false;
				cart.forEach(function (product, i) {
					if (product.product_id == product_id) {
						duplicate = true;
					}
				});
				return duplicate;
			}

			function getTotalPrice() {
				var totalPrice = 0.00;
				cart.forEach(function (item) {
					var price = item.totalPrice.split('£');
					price = parseFloat(price[1]);
					totalPrice += price;
				});
				totalPrice = totalPrice.toFixed(2);
				return ('£ ' + totalPrice);
			}

			function updateCartItem(updatedItem) {
				if (cart.length) {
					cart.forEach(function (item, i) {
						if(item.product_id == updatedItem.product_id) {
							cart[i] = updatedItem;
							$rootScope.cartTotal = getTotalPrice();
						}
					})
				}
			}

			function setDeliveryMethod (methodName) {
				deliveryMethod = methodName;
			}

			function getDeliveryMethod () {
				return deliveryMethod;
			}

			function setPaymentMethod (methodName) {
				payementMethod = methodName;
			}

			function getPaymentMethod () {
				return payementMethod;
			}

			return {
				addToCart: addToCart,
				removeFromCart: removeFromCart,
				viewCart: viewCart,
				getCartSize: getCartSize,
				checkProduct: checkProduct,
				getTotalPrice: getTotalPrice,
				updateCartItem: updateCartItem,
				setDeliveryMethod: setDeliveryMethod,
				setPaymentMethod: setPaymentMethod
			}
		});

}());
